Jivo class final

Entry point

Static Properties

debugging JVDebugging Debugging
Helps debugging the SDK
no setter
display JVDisplay Display
Responsible for everything related to the visual representation of chat on screen.
no setter
notifications JVNotifications Notifications
Contains methods responsible for setting up and processing Push Notifications.
no setter
session JVSession Session
Responsible for everything related to the communication session, such as connection and client data.
no setter