display property
JVDisplay
get
display
Responsible for everything related to the visual representation of chat on screen.
Implementation
static JVDisplay get display => JivoPlugin.instance.display;
Responsible for everything related to the visual representation of chat on screen.
static JVDisplay get display => JivoPlugin.instance.display;